==> qt-creator-2.7.1-src.zip: qt-creator-2.7.1-src/src/plugins/madde/maemopublishingwizardfactories.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/
#ifndef MAEMOPUBLISHINGSERVICE_H
#define MAEMOPUBLISHINGSERVICE_H

#include <projectexplorer/publishing/ipublishingwizardfactory.h>

namespace Core {
class SshRemoteProcessRunner;
}

namespace Madde {
namespace Internal {

class MaemoPublishingWizardFactoryFremantleFree
    : public ProjectExplorer::IPublishingWizardFactory
{
    Q_OBJECT
public:
    explicit MaemoPublishingWizardFactoryFremantleFree(QObject *parent =0);
private:
    QString displayName() const;
    QString description() const;
    bool canCreateWizard(const ProjectExplorer::Project *project) const;
    QWizard *createWizard(const ProjectExplorer::Project *project) const;
};

} // namespace Internal
} // namespace Madde

#endif // MAEMOPUBLISHINGSERVICE_H

==> qt-creator-2.8.0-src.zip: qt-creator-2.8.0-src/src/plugins/madde/maemopublishingwizardfactories.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/
#ifndef MAEMOPUBLISHINGWIZARDFACTORIES_H
#define MAEMOPUBLISHINGWIZARDFACTORIES_H

#include <projectexplorer/publishing/ipublishingwizardfactory.h>

namespace Core {
class SshRemoteProcessRunner;
}

namespace Madde {
namespace Internal {

class MaemoPublishingWizardFactoryFremantleFree
    : public ProjectExplorer::IPublishingWizardFactory
{
    Q_OBJECT
public:
    explicit MaemoPublishingWizardFactoryFremantleFree(QObject *parent =0);
private:
    QString displayName() const;
    QString description() const;
    bool canCreateWizard(const ProjectExplorer::Project *project) const;
    QWizard *createWizard(const ProjectExplorer::Project *project) const;
};

} // namespace Internal
} // namespace Madde

#endif // MAEMOPUBLISHINGWIZARDFACTORIES_H
